pub struct PlainComment;Expand description
Token used to generate plain Rust comments in the output. Used as a marker in front of the string literal to generate a plain comment. Usage:
use sourcegen_cli::tokens::PlainComment;
let _output = quote::quote! {
#PlainComment "GeneratedComment"
struct Test;
};Generated output will contain a plain comment:
// Generated comment
struct Test;Trait Implementations
Sourceimpl ToTokens for PlainComment
impl ToTokens for PlainComment
Sourcefn to_tokens(&self, tokens: &mut TokenStream)
fn to_tokens(&self, tokens: &mut TokenStream)
Sourcefn to_token_stream(&self) -> TokenStream
fn to_token_stream(&self) -> TokenStream
Sourcefn into_token_stream(self) -> TokenStreamwhere
Self: Sized,
fn into_token_stream(self) -> TokenStreamwhere
Self: Sized,