[][src]Struct sourcegen_cli::tokens::PlainComment

pub struct PlainComment;

Token used to generate plain Rust comments in the output. Used as a marker in front of the string literal to generate a plain comment. Usage:

use sourcegen_cli::tokens::PlainComment;
let _output = quote::quote! {
    #PlainComment "GeneratedComment"
    struct Test;
};

Generated output will contain a plain comment:

// Generated comment
struct Test;